@@ -11,14 +11,14 @@ test_that("setup_r5 - expected behavior", {
   testthat::expect_message( setup_r5(data_path = path, verbose = F, temp_dir = TRUE) )
   testthat::expect_message( setup_r5(data_path = path, verbose = T, temp_dir = TRUE) )
 
-  testthat::expect_message( setup_r5(data_path = path, use_elevation=T, temp_dir = TRUE) )
+  testthat::expect_message( setup_r5(data_path = path, elevation="TOBLER", temp_dir = TRUE) )
 
   # remove files GTFS
   #  file.rename(file.path(path, "poa.zip"), file.path(path, "poa.x"))
   # testthat::expect_message( setup_r5(data_path = path, verbose = F) )
   #  file.rename(file.path(path, "poa.x"), file.path(path, "poa.zip"))
 
-  testthat::expect_message(setup_r5(data_path = path, version='6.4.0', verbose = F, temp_dir = TRUE))
+  # testthat::expect_message(setup_r5(data_path = path, version='6.4.0', verbose = F, temp_dir = TRUE))
 
 })
 
@@ -32,7 +32,7 @@ test_that("setup_r5 - expected errors", {
   testthat::expect_error( setup_r5(data_path = 'a') )
   testthat::expect_error(setup_r5(data_path = path, verbose = 'a'))
   testthat::expect_error(setup_r5(data_path = path, temp_dir = 'a'))
-  testthat::expect_error(setup_r5(data_path = path, use_elevation = 'a'))
+  # testthat::expect_error(setup_r5(data_path = path, elevation = 'a'))
 #  testthat::expect_error(setup_r5(data_path = path, version = 'a'))
 
   # No OSM data
@@ -63,5 +63,3 @@ test_that("'overwrite' parameter works correctly", {
   )
 
 })
-
-stop_r5()
